@@ -4,18 +4,19 @@ import (
 	"sync"
 	"testing"
 
+	"github.com/dundee/gdu/internal/testdir"
 	"github.com/stretchr/testify/assert"
 )
 
 func TestProcessDir(t *testing.T) {
-	fin := CreateTestDir()
+	fin := testdir.CreateTestDir()
 	defer fin()
 
 	dir := ProcessDir("test_dir", &CurrentProgress{Mutex: &sync.Mutex{}}, func(_ string) bool { return false })
 
 	// test dir info
 	assert.Equal(t, "test_dir", dir.Name)
-	assert.Equal(t, int64(7), dir.Size)
+	assert.Equal(t, int64(7+4096*3), dir.Size)
 	assert.Equal(t, 5, dir.ItemCount)
 	assert.True(t, dir.IsDir)
 
@@ -35,7 +36,7 @@ func TestProcessDir(t *testing.T) {
 }
 
 func TestIgnoreDir(t *testing.T) {
-	fin := CreateTestDir()
+	fin := testdir.CreateTestDir()
 	defer fin()
 
 	dir := ProcessDir("test_dir", &CurrentProgress{Mutex: &sync.Mutex{}}, func(_ string) bool { return true })
@@ -45,7 +46,7 @@ func TestIgnoreDir(t *testing.T) {
 }
 
 func BenchmarkProcessDir(b *testing.B) {
-	fin := CreateTestDir()
+	fin := testdir.CreateTestDir()
 	defer fin()
 
 	b.ResetTimer()
