@@ -4,7 +4,7 @@ import (
 	"bytes"
 	"testing"
 
-	"github.com/dundee/gdu/analyze"
+	"github.com/dundee/gdu/internal/testdir"
 	"github.com/stretchr/testify/assert"
 )
 
@@ -18,7 +18,7 @@ func TestVersion(t *testing.T) {
 }
 
 func TestAnalyzePath(t *testing.T) {
-	fin := analyze.CreateTestDir()
+	fin := testdir.CreateTestDir()
 	defer fin()
 
 	buff := bytes.NewBuffer(make([]byte, 10))
@@ -29,7 +29,7 @@ func TestAnalyzePath(t *testing.T) {
 }
 
 func TestAnalyzePathWithGui(t *testing.T) {
-	fin := analyze.CreateTestDir()
+	fin := testdir.CreateTestDir()
 	defer fin()
 
 	buff := bytes.NewBuffer(make([]byte, 10))
@@ -38,18 +38,18 @@ func TestAnalyzePathWithGui(t *testing.T) {
 }
 
 func TestListDevices(t *testing.T) {
-	fin := analyze.CreateTestDir()
+	fin := testdir.CreateTestDir()
 	defer fin()
 
 	buff := bytes.NewBuffer(make([]byte, 10))
 
 	Run(&RunFlags{LogFile: "/dev/null", ShowDisks: true}, nil, false, buff, true)
 
-	assert.Contains(t, buff.String(), "dev")
+	assert.Contains(t, buff.String(), "Device")
 }
 
 func TestListDevicesWithGui(t *testing.T) {
-	fin := analyze.CreateTestDir()
+	fin := testdir.CreateTestDir()
 	defer fin()
 
 	buff := bytes.NewBuffer(make([]byte, 10))
