@@ -10,26 +10,29 @@ import (
 	"time"
 
 	"github.com/dundee/gdu/analyze"
+	"github.com/dundee/gdu/device"
 	"github.com/fatih/color"
 )
 
 // UI struct
 type UI struct {
-	output         io.Writer
-	ignoreDirPaths map[string]bool
-	useColors      bool
-	showProgress   bool
-	red            *color.Color
-	orange         *color.Color
-	blue           *color.Color
+	output           io.Writer
+	ignoreDirPaths   map[string]bool
+	useColors        bool
+	showProgress     bool
+	showApparentSize bool
+	red              *color.Color
+	orange           *color.Color
+	blue             *color.Color
 }
 
 // CreateStdoutUI creates UI for stdout
-func CreateStdoutUI(output io.Writer, useColors bool, showProgress bool) *UI {
+func CreateStdoutUI(output io.Writer, useColors bool, showProgress bool, showApparentSize bool) *UI {
 	ui := &UI{
-		output:       output,
-		useColors:    useColors,
-		showProgress: showProgress,
+		output:           output,
+		useColors:        useColors,
+		showProgress:     showProgress,
+		showApparentSize: showApparentSize,
 	}
 
 	ui.red = color.New(color.FgRed).Add(color.Bold)
@@ -44,15 +47,15 @@ func CreateStdoutUI(output io.Writer, useColors bool, showProgress bool) *UI {
 }
 
 // ListDevices lists mounted devices and shows their disk usage
-func (ui *UI) ListDevices(getter analyze.DevicesInfoGetter) {
-	devices, err := getter("/proc/mounts")
+func (ui *UI) ListDevices(getter device.DevicesInfoGetter) {
+	devices, err := getter.GetDevicesInfo()
 	if err != nil {
 		panic(err)
 	}
 
 	maxDeviceNameLenght := maxInt(maxLength(
 		devices,
-		func(device *analyze.Device) string { return device.Name },
+		func(device *device.Device) string { return device.Name },
 	), len("Devices"))
 
 	var sizeLength, percentLength int
@@ -115,15 +118,15 @@ func (ui *UI) AnalyzePath(path string, analyzer analyze.Analyzer, _ *analyze.Fil
 	if ui.showProgress {
 		wait.Add(1)
 		go func() {
+			defer wait.Done()
 			ui.updateProgress(progress)
-			wait.Done()
 		}()
 	}
 
 	wait.Add(1)
 	go func() {
+		defer wait.Done()
 		dir = analyzer(abspath, progress, ui.ShouldDirBeIgnored)
-		wait.Done()
 	}()
 
 	wait.Wait()
@@ -137,16 +140,24 @@ func (ui *UI) AnalyzePath(path string, analyzer analyze.Analyzer, _ *analyze.Fil
 		lineFormat = "%9s %s\n"
 	}
 
+	var size int64
+
 	for _, file := range dir.Files {
+		if ui.showApparentSize {
+			size = file.Size
+		} else {
+			size = file.Usage
+		}
+
 		if file.IsDir {
 			fmt.Fprintf(ui.output,
 				lineFormat,
-				ui.formatSize(file.Size),
+				ui.formatSize(size),
 				ui.blue.Sprintf("/"+file.Name))
 		} else {
 			fmt.Fprintf(ui.output,
 				lineFormat,
-				ui.formatSize(file.Size),
+				ui.formatSize(size),
 				file.Name)
 		}
 	}
@@ -199,19 +210,21 @@ func (ui *UI) updateProgress(progress *analyze.CurrentProgress) {
 }
 
 func (ui *UI) formatSize(size int64) string {
-	if size > 1e12 {
+	switch {
+	case size > 1e12:
 		return ui.orange.Sprintf("%.1f", float64(size)/math.Pow(2, 40)) + " TiB"
-	} else if size > 1e9 {
+	case size > 1e9:
 		return ui.orange.Sprintf("%.1f", float64(size)/math.Pow(2, 30)) + " GiB"
-	} else if size > 1e6 {
+	case size > 1e6:
 		return ui.orange.Sprintf("%.1f", float64(size)/math.Pow(2, 20)) + " MiB"
-	} else if size > 1e3 {
+	case size > 1e3:
 		return ui.orange.Sprintf("%.1f", float64(size)/math.Pow(2, 10)) + " KiB"
+	default:
+		return ui.orange.Sprintf("%d", size) + " B"
 	}
-	return ui.orange.Sprintf("%d", size) + " B"
 }
 
-func maxLength(list []*analyze.Device, keyGetter func(*analyze.Device) string) int {
+func maxLength(list []*device.Device, keyGetter func(*device.Device) string) int {
 	maxLen := 0
 	var s string
 	for _, item := range list {
