@@ -8,6 +8,9 @@ import (
 	"time"
 
 	"github.com/dundee/gdu/analyze"
+	"github.com/dundee/gdu/device"
+	"github.com/dundee/gdu/internal/testdev"
+	"github.com/dundee/gdu/internal/testdir"
 	"github.com/gdamore/tcell/v2"
 	"github.com/stretchr/testify/assert"
 )
@@ -18,18 +21,20 @@ func TestFooter(t *testing.T) {
 	simScreen.Init()
 	simScreen.SetSize(15, 15)
 
-	ui := CreateUI(simScreen, false)
+	ui := CreateUI(simScreen, false, true)
 
 	dir := analyze.File{
 		Name:      "xxx",
 		BasePath:  ".",
 		Size:      5,
+		Usage:     4096,
 		ItemCount: 2,
 	}
 
 	file := analyze.File{
 		Name:      "yyy",
 		Size:      2,
+		Usage:     4096,
 		ItemCount: 1,
 		Parent:    &dir,
 	}
@@ -44,7 +49,7 @@ func TestFooter(t *testing.T) {
 
 	b, _, _ := simScreen.GetContents()
 
-	text := []byte(" Apparent size: 5 B Items: 2")
+	text := []byte(" Total disk usage: 4.0 KiB Apparent size: 5 B Items: 2")
 	for i, r := range b {
 		if i >= len(text) {
 			break
@@ -61,7 +66,7 @@ func TestUpdateProgress(t *testing.T) {
 
 	progress := &analyze.CurrentProgress{Mutex: &sync.Mutex{}, Done: true}
 
-	ui := CreateUI(simScreen, false)
+	ui := CreateUI(simScreen, false, false)
 	progress.CurrentItemName = "xxx"
 	ui.updateProgress(progress)
 	assert.True(t, true)
@@ -73,30 +78,30 @@ func TestHelp(t *testing.T) {
 	simScreen.Init()
 	simScreen.SetSize(50, 50)
 
-	ui := CreateUI(simScreen, false)
+	ui := CreateUI(simScreen, false, true)
 	ui.showHelp()
 	ui.help.Draw(simScreen)
 	simScreen.Show()
 
 	b, _, _ := simScreen.GetContents()
 
-	cells := b[257 : 257+7]
+	cells := b[264 : 264+9]
 
-	text := []byte("selected")
+	text := []byte("directory")
 	for i, r := range cells {
 		assert.Equal(t, text[i], r.Bytes[0])
 	}
 }
 
 func TestDeleteDir(t *testing.T) {
-	fin := analyze.CreateTestDir()
+	fin := testdir.CreateTestDir()
 	defer fin()
 
 	simScreen := tcell.NewSimulationScreen("UTF-8")
 	simScreen.Init()
 	simScreen.SetSize(50, 50)
 
-	ui := CreateUI(simScreen, true)
+	ui := CreateUI(simScreen, true, false)
 	ui.askBeforeDelete = false
 
 	ui.AnalyzePath("test_dir", analyze.ProcessDir, nil)
@@ -117,6 +122,8 @@ func TestDeleteDir(t *testing.T) {
 		time.Sleep(10 * time.Millisecond)
 		simScreen.InjectKey(tcell.KeyRune, 'd', 1)
 		time.Sleep(10 * time.Millisecond)
+		simScreen.InjectKey(tcell.KeyRune, 'a', 1)
+		time.Sleep(10 * time.Millisecond)
 		simScreen.InjectKey(tcell.KeyRune, 'q', 1)
 		time.Sleep(10 * time.Millisecond)
 	}()
@@ -127,14 +134,14 @@ func TestDeleteDir(t *testing.T) {
 }
 
 func TestDoNotDeleteParentDir(t *testing.T) {
-	fin := analyze.CreateTestDir()
+	fin := testdir.CreateTestDir()
 	defer fin()
 
 	simScreen := tcell.NewSimulationScreen("UTF-8")
 	simScreen.Init()
 	simScreen.SetSize(50, 50)
 
-	ui := CreateUI(simScreen, true)
+	ui := CreateUI(simScreen, true, true)
 	ui.askBeforeDelete = false
 
 	ui.AnalyzePath("test_dir", analyze.ProcessDir, nil)
@@ -155,14 +162,14 @@ func TestDoNotDeleteParentDir(t *testing.T) {
 }
 
 func TestDeleteDirWithConfirm(t *testing.T) {
-	fin := analyze.CreateTestDir()
+	fin := testdir.CreateTestDir()
 	defer fin()
 
 	simScreen := tcell.NewSimulationScreen("UTF-8")
 	simScreen.Init()
 	simScreen.SetSize(50, 50)
 
-	ui := CreateUI(simScreen, false)
+	ui := CreateUI(simScreen, false, false)
 
 	ui.AnalyzePath("test_dir", analyze.ProcessDir, nil)
 
@@ -192,14 +199,14 @@ func TestDeleteDirWithConfirm(t *testing.T) {
 }
 
 func TestShowConfirm(t *testing.T) {
-	fin := analyze.CreateTestDir()
+	fin := testdir.CreateTestDir()
 	defer fin()
 
 	simScreen := tcell.NewSimulationScreen("UTF-8")
 	simScreen.Init()
 	simScreen.SetSize(50, 50)
 
-	ui := CreateUI(simScreen, true)
+	ui := CreateUI(simScreen, true, true)
 
 	ui.AnalyzePath("test_dir", analyze.ProcessDir, nil)
 
@@ -235,14 +242,14 @@ func TestShowConfirm(t *testing.T) {
 }
 
 func TestRescan(t *testing.T) {
-	fin := analyze.CreateTestDir()
+	fin := testdir.CreateTestDir()
 	defer fin()
 
 	simScreen := tcell.NewSimulationScreen("UTF-8")
 	simScreen.Init()
 	simScreen.SetSize(50, 50)
 
-	ui := CreateUI(simScreen, true)
+	ui := CreateUI(simScreen, true, false)
 
 	ui.AnalyzePath("test_dir", analyze.ProcessDir, nil)
 
@@ -273,8 +280,8 @@ func TestShowDevices(t *testing.T) {
 	simScreen.Init()
 	simScreen.SetSize(50, 50)
 
-	ui := CreateUI(simScreen, false)
-	ui.ListDevices(getDevicesInfoMock)
+	ui := CreateUI(simScreen, false, true)
+	ui.ListDevices(getDevicesInfoMock())
 	ui.table.Draw(simScreen)
 	simScreen.Show()
 
@@ -296,8 +303,8 @@ func TestShowDevicesBW(t *testing.T) {
 	simScreen.Init()
 	simScreen.SetSize(50, 50)
 
-	ui := CreateUI(simScreen, true)
-	ui.ListDevices(getDevicesInfoMock)
+	ui := CreateUI(simScreen, true, false)
+	ui.ListDevices(getDevicesInfoMock())
 	ui.table.Draw(simScreen)
 	simScreen.Show()
 
@@ -318,10 +325,10 @@ func TestSelectDevice(t *testing.T) {
 	simScreen.Init()
 	simScreen.SetSize(50, 50)
 
-	ui := CreateUI(simScreen, true)
+	ui := CreateUI(simScreen, true, true)
 	ui.analyzer = analyzeMock
 	ui.SetIgnoreDirPaths([]string{"/proc"})
-	ui.ListDevices(getDevicesInfoMock)
+	ui.ListDevices(getDevicesInfoMock())
 
 	go func() {
 		time.Sleep(100 * time.Millisecond)
@@ -338,14 +345,14 @@ func TestSelectDevice(t *testing.T) {
 }
 
 func TestKeys(t *testing.T) {
-	fin := analyze.CreateTestDir()
+	fin := testdir.CreateTestDir()
 	defer fin()
 
 	simScreen := tcell.NewSimulationScreen("UTF-8")
 	simScreen.Init()
 	simScreen.SetSize(50, 50)
 
-	ui := CreateUI(simScreen, false)
+	ui := CreateUI(simScreen, false, false)
 	ui.askBeforeDelete = false
 
 	ui.AnalyzePath("test_dir", analyze.ProcessDir, nil)
@@ -378,14 +385,14 @@ func TestKeys(t *testing.T) {
 }
 
 func TestSetIgnoreDirPaths(t *testing.T) {
-	fin := analyze.CreateTestDir()
+	fin := testdir.CreateTestDir()
 	defer fin()
 
 	simScreen := tcell.NewSimulationScreen("UTF-8")
 	simScreen.Init()
 	simScreen.SetSize(50, 50)
 
-	ui := CreateUI(simScreen, false)
+	ui := CreateUI(simScreen, false, true)
 
 	path, _ := filepath.Abs("test_dir/nested/subnested")
 	ui.SetIgnoreDirPaths([]string{path})
@@ -421,14 +428,17 @@ func analyzeMock(path string, progress *analyze.CurrentProgress, ignore analyze.
 	}
 }
 
-func getDevicesInfoMock(_ string) ([]*analyze.Device, error) {
-	item := &analyze.Device{
+func getDevicesInfoMock() device.DevicesInfoGetter {
+	item := &device.Device{
 		Name:       "/dev/root",
 		MountPoint: "/",
 	}
-	item2 := &analyze.Device{
+	item2 := &device.Device{
 		Name:       "/dev/boot",
 		MountPoint: "/boot",
 	}
-	return []*analyze.Device{item, item2}, nil
+
+	mock := testdev.DevicesInfoGetterMock{}
+	mock.Devices = []*device.Device{item, item2}
+	return mock
 }
